# Word.pm
#
# DESCRIPTION:
# Definition of a Word class. Includes fields for
#  word, lemma, POS, word-sense
#
# Copyright (c) 2004 Rada Mihalcea
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
#
# CHANGE LOG
#
# Date          Author          Change
# =======================================================================
# 11-24-2003    Rada            initial version 
# =======================================================================


package Word;


# Constructor.
#
sub new {
    my $class = shift;
    my ($string) = @_;
    my $self;

    # check if current example *seems* valid
    if(!($string =~ /^\<wf/ ||
	 $string =~ /^\<punc/)) {
	print STDERR "Invalid line $string\n";
	exit;
    }


    $self->{id} = "?";
    $self->{word} = "?";   # word
    $self->{pos} = "?";    # part of speech, Treebank tags
    $self->{lemma} = "?";  # lemma
    $self->{sense} = "?";  # lexsn, from WordNet
    $self->{type} = "?";   # can be punct, wsd, ?
                           # only the wsd words are addressed
                           # type=wsd for open class words
    $self->{wnsn} = 0;     # WordNet sense number, version dependent

    $self->{predicted} = 0;# predicted WordNet sense number, version dependent
	
    # Information for QueryData 
    $self->{littlePos} = "?"; # one letter POS, for QueryData
    $self->{querySense} = "?";# querySense format, for QueryData

    # punctuation
    if($string =~ /^\<punc\>([^\<]+)\</) {
	$self->{word} = $1;
	$self->{lemma} = "PUNCT";
	$self->{pos} = "PUNCT";
	$self->{sense} = "?";
	$self->{type} = "punct";	
    }
    # otherwise, it means it's a word
    if($string =~ /^\<wf/) {
	if($string =~ /id=([^ \>]*)/) {
	    $self->{id} = $1;
	}
	    
	if($string =~ /pos=([^ \>]*)/) {
	    $self->{pos} = $1;
	}

	if($string =~ /lemma=([^ \>]*)/) {
	    $self->{lemma} = $1;
	}

	if($string =~ /lexsn=([^ \>]*)/) {
	    $self->{sense} = $self->{lemma}."%".$1;
	}

	if($string=~ /wnsn=([^ \>]*)/) {
	    $self->{wnsn} = $1;
	}
	
	if($string=~ /\>([^\<]*)/) {
	    $self->{word} = $1;
	}

    }

    # create a "small case" POS information -- to be used with QueryData
    if($self->{pos} =~ /^([NJVR])/) {
	$posid = $1;
	$posid =~ tr/[NVJR]/[nvar]/;
	$self->{littlePos} = $posid;
	$self->{type} = "wsd";
    } 

    # and finally create the querySense information -- to be used with QueryData
    $self->{querySense} = "?";
    $self->{wnsn} =~ s/\;.*//g;
    if($self->{sense} =~ /\%(\d)/) {
	$self->{querySense} = $self->{lemma}."#".$self->{littlePos}."#".$self->{wnsn};
    }
    
    bless($self, $class);
    
    return $self;
}

# Destructor.
# nothing for now
sub DESTROY {
}

1;
